package com.example.controller.teacher;

import com.example.dto.AwardsDTO;
import com.example.dto.WorkDTO;
import com.example.result.Result;
import com.example.service.WorkService;
import com.example.vo.AwardsVO;
import com.example.vo.WorkVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@Slf4j
@Api(tags = "老师著作相关接口")
@RequestMapping("/teacher/work")
public class WorkController {
    @Autowired
    private WorkService workService;

    @PostMapping
    @ApiOperation(value = "老师著作上传")
    public Result uploadWork(@RequestBody WorkDTO workDTO) {
        log.info("著作上传，{}", workDTO);
        workService.uploadWork(workDTO);
        return Result.success();
    }

    @PutMapping("/{id}")
    @ApiOperation(value = "修改指定著作")
    public Result updateWork(@RequestBody WorkDTO workDTO, @PathVariable Long id) {
        log.info("修改指定著作:{}", id);
        workService.updateWork(workDTO, id);
        return Result.success();
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "获取指定著作详细信息")
    public Result<WorkVO> getById(@PathVariable Long id) {
        log.info("获取指定著作详细信息:{}", id);
        WorkVO workVO = workService.getById(id);
        return Result.success(workVO);
    }

    @DeleteMapping("/{id}")
    @ApiOperation(value = "删除指定著作")
    public Result deleteById(@PathVariable Long id){
        log.info("删除指定著作:{}",id);
        workService.deleteById(id);
        return Result.success();
    }
}
