package com.example.service.impl;

import com.example.constant.MessageConstant;
import com.example.context.BaseContext;
import com.example.dto.ThesisDTO;
import com.example.entity.Awards;
import com.example.entity.Thesis;
import com.example.exception.ThesisNotFoundException;
import com.example.mapper.ThesisMapper;
import com.example.service.ThesisService;
import com.example.vo.ThesisVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class ThesisServiceImpl implements ThesisService {

    @Autowired
    private ThesisMapper thesisMapper;

    @Override
    public void uploadThesis(ThesisDTO thesisDTO) {
        Thesis thesis = new Thesis();
        BeanUtils.copyProperties(thesisDTO, thesis);
        Long id = BaseContext.getCurrentId();
        thesis.setTeacherId(id);
        thesisMapper.uploadThesis(thesis);
        thesisMapper.addThesisNum(id);
    }

    @Override
    public void updateThesis(ThesisDTO thesisDTO, Long id) {
        Thesis thesis = new Thesis();
        BeanUtils.copyProperties(thesisDTO, thesis);
        thesis.setId(id);
        thesisMapper.updateThesis(thesis);
    }

    @Override
    public ThesisVO getById(Long id) {
        ThesisVO thesisVO = new ThesisVO();
        Thesis thesis = thesisMapper.getById(id);
        if (thesis == null) {
            throw new ThesisNotFoundException(MessageConstant.THESIS_NOT_FOUND);
        }
        BeanUtils.copyProperties(thesis, thesisVO);
        return thesisVO;
    }

    @Override
    public void deleteById(Long id) {
        thesisMapper.deleteById(id);
    }
}
